@@ -21,12 +21,12 @@ import pygame_button
 import pygame_menu
 
 class ConfigFile:
-    def __init__(self, path: str) -> None:
+    def __init__(self, path: str, default_config: Optional[Any] = None) -> None:
         """Should use os.path.abspath for `path`"""
         self.path = path
         self.thread_true = True
 
-        self.config: Any
+        self.config = default_config
         self.load_config()
 
         self.thread = Thread(target=self.update_config)
@@ -34,6 +34,7 @@ class ConfigFile:
 
     def load_config(self) -> None:
         if not os.path.exists(self.path):
+            open(self.path, 'w+').close()
             self.config = {}
         else:
             with open(self.path, 'rb') as f:
@@ -66,7 +67,7 @@ class Eaves:
             str: lambda status: exec('self.current_status = status'),
             tuple[pygame_menu.Menu, list[Event]]: self.handle_menus
         }
-        self.fps_cap: float = 60.0
+        self.fps_cap: int = 60
         self.clock = pygame.time.Clock()
         self.handlers_to_load: list[str] = []
         self.res: Optional[tuple[int, int]] = None
